#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 vty
version:              5.32
visibility:           public
id:                   vty-5.32-48KPQt5k4MB3fPJLDncSVO
key:                  vty-5.32-48KPQt5k4MB3fPJLDncSVO
license:              BSD-3-Clause
maintainer:           Jonathan Daugherty (cygnus@foobox.com)
author:               AUTHORS
homepage:             https://github.com/jtdaugherty/vty
synopsis:             A simple terminal UI library
description:
    vty is terminal GUI library in the niche of ncurses. It is intended to
    be easy to use, have no confusing corner cases, and good support for
    common terminal types.

    See the @vty-examples@ package as well as the program
    @test/interactive_terminal_test.hs@ included in the @vty@ package for
    examples on how to use the library.

    Import the "Graphics.Vty" convenience module to get access to the core
    parts of the library.

    &#169; 2006-2007 Stefan O'\''Rear; BSD3 license.

    &#169; Corey O'\''Connor; BSD3 license.

    &#169; Jonathan Daugherty; BSD3 license.

category:             User Interfaces
abi:                  ed31cc013084a055e8ae403c61ee817e
exposed:              True
exposed-modules:
    Codec.Binary.UTF8.Debug Data.Terminfo.Eval Data.Terminfo.Parse
    Graphics.Text.Width Graphics.Vty Graphics.Vty.Attributes
    Graphics.Vty.Attributes.Color Graphics.Vty.Config
    Graphics.Vty.Debug Graphics.Vty.DisplayAttributes
    Graphics.Vty.Error Graphics.Vty.Image Graphics.Vty.Image.Internal
    Graphics.Vty.Inline Graphics.Vty.Inline.Unsafe Graphics.Vty.Input
    Graphics.Vty.Input.Classify Graphics.Vty.Input.Classify.Parse
    Graphics.Vty.Input.Classify.Types Graphics.Vty.Input.Events
    Graphics.Vty.Input.Focus Graphics.Vty.Input.Loop
    Graphics.Vty.Input.Mouse Graphics.Vty.Input.Paste
    Graphics.Vty.Input.Terminfo Graphics.Vty.Output
    Graphics.Vty.Output.Interface Graphics.Vty.Output.Mock
    Graphics.Vty.Output.TerminfoBased Graphics.Vty.Output.XTermColor
    Graphics.Vty.Picture Graphics.Vty.PictureToSpans Graphics.Vty.Span
    Graphics.Vty.UnicodeWidthTable.IO
    Graphics.Vty.UnicodeWidthTable.Install
    Graphics.Vty.UnicodeWidthTable.Query
    Graphics.Vty.UnicodeWidthTable.Types

hidden-modules:
    Graphics.Vty.Attributes.Color240 Graphics.Vty.Debug.Image
    Graphics.Vty.Input.Terminfo.ANSIVT

import-dirs:          /usr/lib/ghc-8.10.3/site-local/vty-5.32
library-dirs:         /usr/lib/ghc-8.10.3/site-local/vty-5.32
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.3/vty-5.32
hs-libraries:         HSvty-5.32-48KPQt5k4MB3fPJLDncSVO
depends:
    ansi-terminal-0.11-2SXi8ZhU18i2uWLidRUotS base-4.14.1.0
    binary-0.8.8.0 blaze-builder-0.4.2.1-KRXf5d4GbjLDdq3vlVdrGQ
    bytestring-0.10.12.0 containers-0.6.2.1 deepseq-1.4.4.0
    directory-1.3.6.0 filepath-1.4.2.1
    hashable-1.3.0.0-1CyJarTczNyI67reXuzvxw
    microlens-0.4.12.0-LWmCgM3D0eIxbRgAEzd8k
    microlens-mtl-0.2.0.1-3tNQgwbNspG9ZtqGot68nU
    microlens-th-0.4.3.9-8lY9YzOSn74KKUTb0A8pMI mtl-2.2.2
    parallel-3.2.2.0-HTf2o2horULDwL7cXUB9uv parsec-3.1.14.0 stm-2.5.0.0
    terminfo-0.4.1.4 text-1.2.4.1 transformers-0.5.6.2 unix-2.7.2.2
    utf8-string-1.0.2-7pqBkplor7g1hjwTjVt3SV
    vector-0.12.2.0-8ehm6YCQqIm9C6Fn68BeE2

haddock-interfaces:   /usr/share/doc/haskell-vty/html/vty.haddock
haddock-html:         /usr/share/doc/haskell-vty/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

